@@ -51,6 +51,7 @@ func init() {
 		"builtins":       argFunc0(nil),
 		"input":          argFunc0(nil),
 		"modulemeta":     argFunc0(nil),
+		"debug":          argFunc1(nil),
 		"abs":            argFunc0(funcAbs),
 		"length":         argFunc0(funcLength),
 		"utf8bytelength": argFunc0(funcUtf8ByteLength),
@@ -602,7 +603,7 @@ func indices(vs, xs []any) any {
 		return rs
 	}
 	for i := 0; i <= len(vs)-len(xs); i++ {
-		if compare(vs[i:i+len(xs)], xs) == 0 {
+		if Compare(vs[i:i+len(xs)], xs) == 0 {
 			rs = append(rs, i)
 		}
 	}
@@ -615,7 +616,7 @@ func funcIndex(v, x any) any {
 			return nil
 		}
 		for i := 0; i <= len(vs)-len(xs); i++ {
-			if compare(vs[i:i+len(xs)], xs) == 0 {
+			if Compare(vs[i:i+len(xs)], xs) == 0 {
 				return i
 			}
 		}
@@ -629,7 +630,7 @@ func funcRindex(v, x any) any {
 			return nil
 		}
 		for i := len(vs) - len(xs); i >= 0; i-- {
-			if compare(vs[i:i+len(xs)], xs) == 0 {
+			if Compare(vs[i:i+len(xs)], xs) == 0 {
 				return i
 			}
 		}
@@ -883,7 +884,7 @@ func funcToHTML(v any) any {
 func funcToURI(v any) any {
 	switch x := funcToString(v).(type) {
 	case string:
-		return url.QueryEscape(x)
+		return strings.ReplaceAll(url.QueryEscape(x), "+", "%20")
 	default:
 		return x
 	}
@@ -892,7 +893,7 @@ func funcToURI(v any) any {
 func funcToURId(v any) any {
 	switch x := funcToString(v).(type) {
 	case string:
-		x, err := url.QueryUnescape(x)
+		x, err := url.QueryUnescape(strings.ReplaceAll(x, "+", "%2B"))
 		if err != nil {
 			return &func0WrapError{"@urid", v, err}
 		}
@@ -1188,7 +1189,7 @@ type rangeIter struct {
 }
 
 func (iter *rangeIter) Next() (any, bool) {
-	if compare(iter.step, 0)*compare(iter.value, iter.end) >= 0 {
+	if Compare(iter.step, 0)*Compare(iter.value, iter.end) >= 0 {
 		return nil, false
 	}
 	v := iter.value
@@ -1259,7 +1260,7 @@ func minMaxBy(vs, xs []any, isMin bool) any {
 	}
 	i, j, x := 0, 0, xs[0]
 	for i++; i < len(xs); i++ {
-		if compare(x, xs[i]) > 0 == isMin {
+		if Compare(x, xs[i]) > 0 == isMin {
 			j, x = i, xs[i]
 		}
 	}
@@ -1290,7 +1291,7 @@ func sortItems(name string, v, x any) ([]*sortItem, error) {
 		items[i] = &sortItem{v, xs[i]}
 	}
 	sort.SliceStable(items, func(i, j int) bool {
-		return compare(items[i].key, items[j].key) < 0
+		return Compare(items[i].key, items[j].key) < 0
 	})
 	return items, nil
 }
@@ -1323,7 +1324,7 @@ func funcGroupBy(v, x any) any {
 	rs := []any{}
 	var last any
 	for i, r := range items {
-		if i == 0 || compare(last, r.key) != 0 {
+		if i == 0 || Compare(last, r.key) != 0 {
 			rs, last = append(rs, []any{r.value}), r.key
 		} else {
 			rs[len(rs)-1] = append(rs[len(rs)-1].([]any), r.value)
@@ -1348,7 +1349,7 @@ func uniqueBy(name string, v, x any) any {
 	rs := []any{}
 	var last any
 	for i, r := range items {
-		if i == 0 || compare(last, r.key) != 0 {
+		if i == 0 || Compare(last, r.key) != 0 {
 			rs, last = append(rs, r.value), r.key
 		}
 	}
@@ -1503,10 +1504,7 @@ func (a allocator) makeObject(l int) map[string]any {
 }
 
 func (a allocator) makeArray(l, c int) []any {
-	if c < l {
-		c = l
-	}
-	v := make([]any, l, c)
+	v := make([]any, l, max(l, c))
 	if a != nil {
 		a[reflect.ValueOf(v).Pointer()] = struct{}{}
 	}
@@ -1826,9 +1824,9 @@ func funcBsearch(v, t any) any {
 		return &func1TypeError{"bsearch", v, t}
 	}
 	i := sort.Search(len(vs), func(i int) bool {
-		return compare(vs[i], t) >= 0
+		return Compare(vs[i], t) >= 0
 	})
-	if i < len(vs) && compare(vs[i], t) == 0 {
+	if i < len(vs) && Compare(vs[i], t) == 0 {
 		return i
 	}
 	return -i - 1
@@ -1938,41 +1936,30 @@ func funcStrptime(v, x any) any {
 
 func arrayToTime(a []any, loc *time.Location) (time.Time, error) {
 	var t time.Time
-	if len(a) != 8 {
-		return t, &timeArrayError{}
+	var year, month, day, hour, minute,
+		second, nanosecond, weekday, yearday int
+	for i, p := range []*int{
+		&year, &month, &day, &hour, &minute,
+		&second, &weekday, &yearday,
+	} {
+		if i >= len(a) {
+			break
+		}
+		if i == 5 {
+			if v, ok := toFloat(a[i]); ok {
+				*p = int(v)
+				nanosecond = int((v - math.Floor(v)) * 1e9)
+			} else {
+				return t, &timeArrayError{}
+			}
+		} else if v, ok := toInt(a[i]); ok {
+			*p = v
+		} else {
+			return t, &timeArrayError{}
+		}
 	}
-	var y, m, d, h, min, sec, nsec int
-	var ok bool
-	if y, ok = toInt(a[0]); !ok {
-		return t, &timeArrayError{}
-	}
-	if m, ok = toInt(a[1]); ok {
-		m++
-	} else {
-		return t, &timeArrayError{}
-	}
-	if d, ok = toInt(a[2]); !ok {
-		return t, &timeArrayError{}
-	}
-	if h, ok = toInt(a[3]); !ok {
-		return t, &timeArrayError{}
-	}
-	if min, ok = toInt(a[4]); !ok {
-		return t, &timeArrayError{}
-	}
-	if x, ok := toFloat(a[5]); ok {
-		sec = int(x)
-		nsec = int((x - math.Floor(x)) * 1e9)
-	} else {
-		return t, &timeArrayError{}
-	}
-	if _, ok = toFloat(a[6]); !ok {
-		return t, &timeArrayError{}
-	}
-	if _, ok = toFloat(a[7]); !ok {
-		return t, &timeArrayError{}
-	}
-	return time.Date(y, time.Month(m), d, h, min, sec, nsec, loc), nil
+	return time.Date(year, time.Month(month+1), day,
+		hour, minute, second, nanosecond, loc), nil
 }
 
 func funcNow(any) any {
